/******************************************************************
Copyright (c) 1996 Novell, Inc. All Rights Reserved.

THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND
TREATIES. USE AND REDISTRIBUTION OF THIS WORK IS SUBJECT TO THE
LICENSE AGREEMENT ACCOMPANYING THE SOFTWARE DEVELOPMENT KIT (SDK)
THAT CONTAINS THIS WORK. PURSUANT TO THE SDK LICENSE AGREEMENT,
NOVELL HEREBY GRANTS TO DEVELOPER A ROYALTY-FREE, NON-EXCLUSIVE
LICENSE TO INCLUDE NOVELL'S SAMPLE CODE IN ITS PRODUCT. NOVELL
GRANTS DEVELOPER WORLDWIDE DISTRIBUTION RIGHTS TO MARKET,
DISTRIBUTE, OR SELL NOVELL'S SAMPLE CODE AS A COMPONENT OF
DEVELOPER'S PRODUCTS. NOVELL SHALL HAVE NO OBLIGATIONS TO
DEVELOPER OR DEVELOPER'S CUSTOMERS WITH RESPECT TO THIS CODE.
******************************************************************/

package com.novell.nds.dirxml.driver.jdbc.db;


import java.text.ParseException;


/**
 * A DB2 timestamp, default format
 * (e&#46;g&#46; "<code>2002-01-01-00&#46;00&#46;00&#46;000000</code>").
 */
public
class DB2Timestamp
    extends DBTimestamp
{
    static private final String DEFAULT_DB_FORMAT = "";


    /**
     * Instantiates a DB2 timestamp, default native format.
     *
     * @param db2Timestamp may be <code>null</code>;
     * the format should be <code>yyyy-mm-dd-hh.mm.ss.ffffff</code>
     */
    public
    DB2Timestamp(String db2Timestamp)
    {
        this(db2Timestamp,
             DEFAULT_CLASS.getName(),
             DEFAULT_DB_FORMAT,
             DEFAULT_IN_FORMAT.toString());
    }//DBTimestamp(String)


    /**
     * Instantiates a DB2 timestamp, default format.
     *
     * @param db2Timestamp may be <code>null</code>;
     * format should be <code>yyyy-mm-dd-hh.mm.ss.ffffff</code>
     * @param sqlClass should be <code>java.sql.Timestamp</code>,
     * <code>java.sql.Date</code> or <code>java.sql.Time</code>;
     * the default value is <code>java.sql.Timestamp</code>
     * @param inFormat this parameter is currently ignored and
     * reserved for future use
     * @param outFormat should be "<code>1</code>" (integer) or
     * "<code>2</code>" (string); the default value is "<code>1</code>"
     * (integer); may be <code>null</code>
     */
    public
    DB2Timestamp
    (
        String db2Timestamp,
        String sqlClass,
        String inFormat,
        String outFormat
    )
    {
        super(db2Timestamp, sqlClass, inFormat, outFormat);
    }


    public
    void
    setDSTime(String db2Timestamp)
        throws  ParseException, IllegalArgumentException
    {
        String odbcTimestamp;

        if(db2Timestamp.length() != DB2.LEN_TIMESTAMP)
        {
            throw new ParseException("Wrong length.  Expected length " + DB2.LEN_TIMESTAMP +
                                     ".  Actual length " + db2Timestamp.length(), 0);
        }

        odbcTimestamp = DB2.ToODBCTimestamp(db2Timestamp);
        setTimestamp(DBLib.NewTimestamp(odbcTimestamp));
    }//setDSTime(String)

}//class DB2Timestamp
